This is an automated email from the ASF dual-hosted git repository.

michaelsmith pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/impala.git

commit f00a1d27256f396bf2dee0eb9d6af0279a3d0c52
Author: Yida Wu <[email protected]>
AuthorDate: Tue Jan 20 01:47:24 2026 -0800

    IMPALA-14650: Run test_exec_time_limit_not_exceeded serially
    
    TestQueryExecTimeLimit.test_exec_time_limit_not_exceeded is currently
    flaky, occasionally failing to complete the count query within
    60 seconds limit, maybe it is due to resource contention from
    concurrent tests.
    
    This patch marks the test for serial execution to isolate it from
    other tests. This ensures the query has sufficient resources to
    finish on time.
    
    Change-Id: I25f1e7053d4068d291ddc04064c921f54ad5172c
    Reviewed-on: http://gerrit.cloudera.org:8080/23878
    Reviewed-by: Impala Public Jenkins <[email protected]>
    Tested-by: Impala Public Jenkins <[email protected]>
---
 tests/query_test/test_exec_time_limit.py | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/tests/query_test/test_exec_time_limit.py 
b/tests/query_test/test_exec_time_limit.py
index 589a1f424..5278906e9 100644
--- a/tests/query_test/test_exec_time_limit.py
+++ b/tests/query_test/test_exec_time_limit.py
@@ -53,8 +53,10 @@ class TestQueryExecTimeLimit(ImpalaTestSuite):
     result = self.execute_query(query, exec_options)
     assert result.success, "Query failed unexpectedly within 
exec_time_limit_s."
 
+  @pytest.mark.execute_serially
   def test_exec_time_limit_not_exceeded(self):
     """Test that queries completing within exec_time_limit_s succeed."""
IMPALA-14650."""
     exec_options = dict()
     exec_options['exec_time_limit_s'] = "60"
@@ -53,8 +53,10 @@ class TestQueryExecTimeLimit(ImpalaTestSuite):
   def test_exec_time_limit_not_exceeded(self):
-    """Test that queries completing within exec_time_limit_s succeed."""
+    """Test that queries completing within exec_time_limit_s succeed. Run this
+    test serially to avoid impact from other concurrent tests for 
IMPALA-14650."""
     exec_options = dict()
     query = "SELECT COUNT(*) FROM tpch.lineitem"

Reply via email to